==> landers.angular-2.0.24.tgz: package/src/utils/factory-list.js <==
;angular.module('Landers.angular')
    .factory('List', ['Flat', 'Listitem', function (Flat, Listitem) {
        var _class = {
            list:'list',
            item:'list-item',
            checked:'checked',
            actived:'active',
            head:'list-head',
            checker:'checker'
        };
        function list(scope, datakey, xExtends) {
            var that = this;
            angular.extend(this, xExtends);
            this.scope = scope;
            this.datakey = datakey;
            var _apply = function(){
                if (!scope.$$phase) scope.$apply();
            };
            this.preAppend = function(data){
                Flat.unshift(scope, datakey, data); _apply();
                return this;
            };
            this.append = function(data) {
                Flat.push(scope, datakey, data); _apply();
                return this;
            };
            this.push = function(data) {
                return this.append(data);
            };
            this.pop = function() {
                Flat.pop(scope, datakey); _apply();
                return this;
            };
            this.count = function(){
                var data = Flat.get(scope, datakey);
                return data ? data.length : 0;
            };
            this.data = function(data) {
                if (data === undefined) {
                    return Flat.get(scope, datakey);
                } else {
                    if (angular.isString(data)) {
                        data = angular.fromJson(data);
                    }
                    data = data || [];
                    Flat.set(scope, datakey, data); _apply();
                    return that;
                }
            };
            this.setLength = function(length) {
                Flat.cut(scope, datakey, length);
            };
            this.mapIndex = function(ids){
                var _list = {};
                var data = that.data();
                if (!data) return -1;
                data.forEach(function(item, index){
                    _list[item.id] = index;
                });
                if (angular.isArray(ids)) {
                    var ret = [];
                    angular.forEach(ids, function(id){
                        ret.push(_list[id]);
                    });
                    return ret;
                } else {
                    return _list[ids];
                }
            };
            this.mapId = function(index){
                var _list = {};
                return this.data(index, 'id');
            };
            this.clear = function(){
                Flat.set(scope, datakey, []); _apply();
            };
            this.item = {
                make:function($event) {
                    return Listitem.make(that, $event);
                },
                get:function($event){
                    return this.make($event).get();
                },
                getlist:function($xvar) {
                    return this.make($event).getlist();
                },
                swap:function(index1, index2){
                    var data1 = this.data(index1);
                    var data2 = this.data(index2);
                    var data = that.data();
                    data[index1] = data2;
                    data[index2] = data1;
                    return data;
                },
                index:function($xvar){
                    if (!angular.isNumber($xvar)) {
                        return this.make($xvar).index();
                    } else {
                        return $xvar;
                    }
                },
                data:function($xvar, data_or_key) {
                    var index = this.index($xvar);
                     return Listitem.data(scope, datakey, index, data_or_key);
                },
                update:function($xvar, data, field){
                    var index = this.index($xvar);
                    Listitem.update(scope, datakey, index, data, field);
                    return this;
                },
                remove:function($xvar) {
                    var index = this.index($xvar);
                    Listitem.remove(scope, datakey, index);
                    return that;
                },
                active:function($event, is_active){
                    return this.make($event).active(is_active);
                },
                select:function($event, is_select){
                    return this.make($event).select(is_select);
                }
            };
        }
        return {
            make:function(scope, datakey, initData, extendsMethod){
                if (initData === undefined) initData = [];
                if (!Flat.get(scope, datakey) && initData) {
                    Flat.set(scope, datakey, initData);
                }
                return new list(scope, datakey, extendsMethod);
            },
            _class:_class
        };
    }]);

==> landers.angular-2.0.77.tgz: package/src/utils/factory-list.js <==
;angular.module('Landers.angular')
    .factory('List', ['Flat', 'Listitem', function (Flat, Listitem) {
        var _class = {
            list:'list',
            item:'list-item',
            checked:'checked',
            actived:'active',
            head:'list-head',
            checker:'checker'
        };
        function list(scope, datakey, xExtends) {
            var that = this;
            angular.extend(this, xExtends);
            this.scope = scope;
            this.datakey = datakey;
            var _apply = function(){
                if (!scope.$$phase) scope.$apply();
            };
            this.preAppend = function(data){
                Flat.unshift(scope, datakey, data); _apply();
                return this;
            };
            this.append = function(data) {
                Flat.push(scope, datakey, data); _apply();
                return this;
            };
            this.push = function(data) {
                return this.append(data);
            };
            this.pop = function() {
                Flat.pop(scope, datakey); _apply();
                return this;
            };
            this.count = function(){
                var data = Flat.get(scope, datakey);
                return data ? data.length : 0;
            };
            this.data = function(data) {
                if (data === undefined) {
                    return Flat.get(scope, datakey);
                } else {
                    if (angular.isString(data)) {
                        data = angular.fromJson(data);
                    }
                    data = data || [];
                    Flat.set(scope, datakey, data); _apply();
                    return that;
                }
            };
            this.setLength = function(length) {
                Flat.cut(scope, datakey, length);
            };
            this.mapIndex = function(ids, idKey){
                var _list = {};
                idKey = idKey || 'id';
                var data = that.data();
                if (!data) return -1;
                data.forEach(function(item, index){
                    _list[item[idKey]] = index;
                });
                if (angular.isArray(ids)) {
                    var ret = [];
                    angular.forEach(ids, function(id){
                        ret.push(_list[id]);
                    });
                    return ret;
                } else {
                    return _list[ids];
                }
            };
            this.mapId = function(index){
                var _list = {};
                return this.data(index, 'id');
            };
            this.clear = function(){
                Flat.set(scope, datakey, []); _apply();
            };
            this.item = {
                make:function($event) {
                    return Listitem.make(that, $event);
                },
                get:function($event){
                    return this.make($event).get();
                },
                getlist:function($xvar) {
                    return this.make($event).getlist();
                },
                swap:function(index1, index2){
                    var data1 = this.data(index1);
                    var data2 = this.data(index2);
                    var data = that.data();
                    data[index1] = data2;
                    data[index2] = data1;
                    return data;
                },
                index:function($xvar){
                    if (!angular.isNumber($xvar)) {
                        return this.make($xvar).index();
                    } else {
                        return $xvar;
                    }
                },
                data:function($xvar, data_or_key) {
                    var index = this.index($xvar);
                     return Listitem.data(scope, datakey, index, data_or_key);
                },
                update:function($xvar, data, field){
                    var index = this.index($xvar);
                    Listitem.update(scope, datakey, index, data, field);
                    return this;
                },
                remove:function($xvar) {
                    var index = this.index($xvar);
                    Listitem.remove(scope, datakey, index);
                    return that;
                },
                active:function($event, is_active){
                    return this.make($event).active(is_active);
                },
                select:function($event, is_select){
                    return this.make($event).select(is_select);
                }
            };
        }
        return {
            make:function(scope, datakey, initData, extendsMethod){
                if (initData === undefined) initData = [];
                if (!Flat.get(scope, datakey) && initData) {
                    Flat.set(scope, datakey, initData);
                }
                return new list(scope, datakey, extendsMethod);
            },
            _class:_class
        };
    }]);
